package SyForm::Class;
BEGIN {
  $SyForm::Class::AUTHORITY = 'cpan:GETTY';
}
# ABSTRACT: Make a SyForm class with fields
$SyForm::Class::VERSION = '0.006';
use Moose;

# TODO

1;

__END__

=pod

=head1 NAME

SyForm::Class - Make a SyForm class with fields

=head1 VERSION

version 0.006

=head1 AUTHOR

Torsten Raudssus <torsten@raudss.us>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Torsten Raudssus.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
